Module hsm

Service used to talk to the hsmd that is passing us the signer requests.

Structs

StagingHsmServer
The StagingHsmServer is used by the plugin to receive incoming requests from the hsmproxy and stages the requests for clients of the Node interface to stream and reply to.