Module tlv

Structs

SerializedTlvStream
A standalone type the represent a binary serialized TlvStream. This is distinct from TlvStream since that expects TLV streams to be encoded as maps in JSON.

Traits

FromBytes
ProtoBuf
Extensions on top of Buf to include LN proto primitives
ProtoBufMut
ToBytes

Type Aliases

CompactSize
TU64
A variant of CompactSize that works on length-delimited buffers and therefore does not require a length prefix